# Metagene

[![Readthedocs](https://readthedocs.org/projects/metagene/badge/?version=latest)](https://metagene.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://img.shields.io/travis/y9c/metagene.svg)](https://travis-ci.com/y9c/metagene)
[![Pypi Releases](https://img.shields.io/pypi/v/metagene.svg)](https://pypi.python.org/pypi/metagene)
[![Downloads](https://pepy.tech/badge/metagene)](https://pepy.tech/project/metagene)

**Metagene Profiling Analysis and Visualization**

(WIP)

## Demo
